Package: funkycells
Title: Functional Data Analysis for Multiplexed Cell Images
Version: 1.1.1
Authors@R: c(
    person("Jeremy", "VanderDoes", , "jeremy.vanderdoes@gmail.com", 
           role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0009-0001-9885-3073")),
    person("Jack", "Hywood", role = "aut",
           comment = c(ORCID = "0000-0002-2028-2629")),
    person("Gregory", "Rice", role = "aut")
  )
Description: Compare variables of interest between (potentially large
    numbers of) spatial interactions and meta-variables. Spatial variables
    are summarized using K, or other, functions, and projected for use in
    a modified random forest model. The model allows comparison of
    functional and non-functional variables to each other and to noise,
    giving statistical significance to the results. Included are
    preparation, modeling, and interpreting tools along with example
    datasets, as described in VanderDoes et al., (2023)
    <doi:10.1101/2023.07.18.549619>.
License: GPL (>= 3)
URL: https://github.com/jrvanderdoes/funkycells,
        https://jrvanderdoes.github.io/funkycells/
BugReports: https://github.com/jrvanderdoes/funkycells/issues
Depends: R (>= 2.10)
Imports: fda, ggplot2, rpart, spatstat.explore, spatstat.geom, stats,
        stringr, tidyr
Suggests: knitr, pROC, rmarkdown, scales, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-08-08 12:48:11 UTC; jerem
Author: Jeremy VanderDoes [aut, cre, cph]
    (<https://orcid.org/0009-0001-9885-3073>),
  Jack Hywood [aut] (<https://orcid.org/0000-0002-2028-2629>),
  Gregory Rice [aut]
Maintainer: Jeremy VanderDoes <jeremy.vanderdoes@gmail.com>
Repository: CRAN
Date/Publication: 2023-08-09 16:00:06 UTC
Built: R 4.6.0; ; 2026-04-25 13:00:57 UTC; unix
