# Generated by roxygen2: do not edit by hand

export(computePseudoROCCurves)
export(funkyForest)
export(funkyModel)
export(getCountData)
export(getKFunction)
export(getKsPCAData)
export(plotPP)
export(plot_K_functions)
export(predict_funkyForest)
export(simulateMeta)
export(simulatePP)
